Function split
pub fn split(rect: Rect) -> (Rect, Rect)Expand description
Splits the canvas into the heatmap and history areas: side by side when the canvas is wide, stacked otherwise.
pub fn split(rect: Rect) -> (Rect, Rect)Splits the canvas into the heatmap and history areas: side by side when the canvas is wide, stacked otherwise.